@@ -9,7 +9,7 @@ function(resp,flag,gr) {
     ndif<-sum(flag)
     dif.items<-names(resp.dif) 
     sparse.resp<-data.frame(matrix(NA,nobs,ndif*ng)) 
-    colnames(sparse.resp)<-paste(rep(dif.items,rep(ng,ndif)),".",rep(1:ng,ndif),sep="") 
+    colnames(sparse.resp)<-paste0(rep(dif.items,rep(ng,ndif)),".",rep(1:ng,ndif)) 
     for (i in 1:ndif) {
       for (j in 1:ng) {
         sparse.resp[gr==gr.label[j],ng*i-ng+j]<-resp.dif[gr==gr.label[j],i] 
